export interface WebformState {
    id: string;
    label: string;
    conditions?: WebformStateCondition;
}
export type BaseWebformStateCondition = {
    id: string;
    name: string;
};
type GenericCondition<T> = BaseWebformStateCondition & T;
type CommonOp = 'eq' | 'neq' | 'regex' | 'in' | 'nin';
type ValueType = 'datasource' | 'hardCoded';
export type DataSourceCondition = GenericCondition<{
    type: 'datasource';
    path: string;
    value: unknown;
    valueType?: ValueType;
    op: CommonOp | 'gt' | 'gte' | 'lt' | 'lte';
}>;
export type PrivilegeCondition = GenericCondition<{
    type: 'privilege';
    value: string;
    valueType?: ValueType;
    op: CommonOp;
}>;
export type CombinationCondition = Omit<GenericCondition<{
    type: 'combination';
    op: 'and' | 'or';
    conditions: WebformStateCondition[];
    name?: string;
}>, 'name'>;
export type ParentStateCondition = GenericCondition<{
    type: 'parentState';
    value: string;
    valueType?: ValueType;
    op: CommonOp;
}>;
export type ReferenceCondition = GenericCondition<{
    type: 'reference';
    ref: string;
}>;
export type WebformStateCondition = DataSourceCondition | PrivilegeCondition | CombinationCondition | ParentStateCondition | ReferenceCondition;
export {};
